@@ -167,7 +167,7 @@ int main(int argc, char*argv[]) {
             {
                 if (*uid > MAX_ID)
                 {
-                   fprintf(stderr, "MAX_ID is %ld and current uid is %ld, please check\n\r", MAX_ID, *uid );
+                   fprintf(stderr, "MAX_ID is %u and current uid is %u, please check\n\r", MAX_ID, *uid );
                    exit (1);
 
                 }
